#ifndef EZTRACE_STATS_MPI_H
#define EZTRACE_STATS_MPI_H
#include <stdio.h>
#include "mpi_ev_codes.h"
#include "eztrace_list.h"
#include "eztrace_convert.h"
#include "eztrace_convert_mpi.h"
#include "eztrace_convert_mpi_p2p.h"
#include "eztrace_hierarchical_array.h"


/* compute point to point messages statistics and print them */
void print_p2p_stats();

/* initialize MPI statistics module */
void init_mpi_stats();

/* dump to disk the list of messages */
void mpi_stats_dump();

void mpi_stats_plot_message_size();

#endif	/* EZTRACE_STATS_MPI_H */
